|PyPI|

.. |PyPI| image:: https://github.com/adxsrc/trad/actions/workflows/python-publish.yml/badge.svg
   :target: https://pypi.org/project/trad/


|Trad|_: Composable Radiative Transfer
======================================

|Trad|_ is a radiative transfer package written in python.
It uses Google's |JAX|_ package for composbility, performance, and
GPU-acceleration.


.. |JAX|  replace:: ``JAX``
.. |Trad| replace:: ``Trad``

.. _JAX:  https://github.com/google/jax
.. _Trad: https://github.com/adxsrc/trad
